@@ -117,7 +117,7 @@ sub o_auth_post {
     }
 
     # parse inputs
-    my $_resource_path = '/connect/token';
+    my $_resource_path = '/v3.0/cells/connect/token';
     if($self->{config}->{api_version} eq "v1.1"){
         $_resource_path = '/oauth2/token';
     }
@@ -197,8 +197,7 @@ sub call_api {
 
     my $_url = $self->{config}{base_url}."/" .$self->{config}{api_version} . $resource_path;
     if($get_token){
-       # $_url = $self->{config}{base_url} . $resource_path;
-       $_url = "https://id.aspose.cloud" . $resource_path;
+        $_url = $self->{config}{base_url} . $resource_path;
     }
 
     # build query 
