@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Represent an area of cells.           ',
                                   class => 'CellArea',
                                   required => [], # TODO
 }                                 );
