@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents chart operate parameter.',
                                   class => 'ChartOperateParameter',
                                   required => [], # TODO
 }                                 );
@@ -128,77 +128,77 @@ __PACKAGE__->method_documentation({
      'chart_index' => {
      	datatype => 'int',
      	base_name => 'ChartIndex',
-     	description => '',
+     	description => 'Represents chart index.',
      	format => '',
      	read_only => '',
      		},
      'chart_type' => {
      	datatype => 'string',
      	base_name => 'ChartType',
-     	description => '',
+     	description => 'Represents chart type.',
      	format => '',
      	read_only => '',
      		},
      'upper_left_row' => {
      	datatype => 'int',
      	base_name => 'UpperLeftRow',
-     	description => '',
+     	description => 'Represents upper left row index of chart.',
      	format => '',
      	read_only => '',
      		},
      'upper_left_column' => {
      	datatype => 'int',
      	base_name => 'UpperLeftColumn',
-     	description => '',
+     	description => 'Represents upper left column index of chart.',
      	format => '',
      	read_only => '',
      		},
      'lower_right_row' => {
      	datatype => 'int',
      	base_name => 'LowerRightRow',
-     	description => '',
+     	description => 'Represents lower right row index of chart.',
      	format => '',
      	read_only => '',
      		},
      'lower_right_column' => {
      	datatype => 'int',
      	base_name => 'LowerRightColumn',
-     	description => '',
+     	description => 'Represents lower right column index of chart.',
      	format => '',
      	read_only => '',
      		},
      'area' => {
      	datatype => 'string',
      	base_name => 'Area',
-     	description => '',
+     	description => 'Represents chart area.',
      	format => '',
      	read_only => '',
      		},
      'is_vertical' => {
      	datatype => 'boolean',
      	base_name => 'IsVertical',
-     	description => '',
+     	description => 'Represents whether to plot the series from a range of cell values by row or by column.',
      	format => '',
      	read_only => '',
      		},
      'category_data' => {
      	datatype => 'string',
      	base_name => 'CategoryData',
-     	description => '',
+     	description => 'Represents chart category data.',
      	format => '',
      	read_only => '',
      		},
      'is_auto_get_serial_name' => {
      	datatype => 'boolean',
      	base_name => 'IsAutoGetSerialName',
-     	description => '',
+     	description => 'Represents whether auto get serial name.',
      	format => '',
      	read_only => '',
      		},
      'title' => {
      	datatype => 'string',
      	base_name => 'Title',
-     	description => '',
+     	description => 'Represents chart title.',
      	format => '',
      	read_only => '',
      		},
