@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -128,42 +128,42 @@ __PACKAGE__->method_documentation({
      'column_character_width' => {
      	datatype => 'boolean',
      	base_name => 'ColumnCharacterWidth',
-     	description => 'Indicates whether copying column width in unit of characters.',
+     	description => 'Indicates whether copying column width in unit of characters. ',
      	format => '',
      	read_only => '',
      		},
      'copy_invalid_formulas_as_values' => {
      	datatype => 'boolean',
      	base_name => 'CopyInvalidFormulasAsValues',
-     	description => 'If the formula is not valid for the dest destination, only copy values.',
+     	description => 'If the formula is not valid for the dest destination, only copy values. ',
      	format => '',
      	read_only => '',
      		},
      'copy_names' => {
      	datatype => 'boolean',
      	base_name => 'CopyNames',
-     	description => 'Indicates whether copying the names.',
+     	description => 'Indicates whether copying the names. ',
      	format => '',
      	read_only => '',
      		},
      'extend_to_adjacent_range' => {
      	datatype => 'boolean',
      	base_name => 'ExtendToAdjacentRange',
-     	description => 'Indicates whether extend ranges when copying the range to adjacent range.',
+     	description => 'Indicates whether extend ranges when copying the range to adjacent range. ',
      	format => '',
      	read_only => '',
      		},
      'refer_to_destination_sheet' => {
      	datatype => 'boolean',
      	base_name => 'ReferToDestinationSheet',
-     	description => 'When copying the range in the same file and the chart refers to the source sheet,  False means the copied chart`s data source will not be changed. True means the  copied chart`s data source refers to the destination sheet.            ',
+     	description => 'When copying the range in the same file and the chart refers to the source sheet,            False means the copied chart`s data source will not be changed.            True means the copied chart`s data source refers to the destination sheet. ',
      	format => '',
      	read_only => '',
      		},
      'refer_to_sheet_with_same_name' => {
      	datatype => 'boolean',
      	base_name => 'ReferToSheetWithSameName',
-     	description => '',
+     	description => 'In ms excel, when copying formulas which refer to other worksheets while copying a worksheet to another one,            the copied formulas should refer to source workbook.            However, for some situations user may need the copied formulas refer to worksheets with the same name            in the same workbook, such as when those worksheets have been copied before this copy operation,            then this property should be kept as true. ',
      	format => '',
      	read_only => '',
      		},    
