@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the datetime`s group setting.',
                                   class => 'DateTimeGroupItem',
                                   required => [], # TODO
 }                                 );
