@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# PostWorkbookCalculateFormulaRequest.name :   ,
-# PostWorkbookCalculateFormulaRequest.options :   ,
-# PostWorkbookCalculateFormulaRequest.ignoreError :   ,
-# PostWorkbookCalculateFormulaRequest.folder :   ,
-# PostWorkbookCalculateFormulaRequest.storageName :    
+# PostWorkbookCalculateFormulaRequest.name : The file name.  ,
+# PostWorkbookCalculateFormulaRequest.options : CalculationOptions Calculation Options.  ,
+# PostWorkbookCalculateFormulaRequest.ignoreError : ignore Error.  ,
+# PostWorkbookCalculateFormulaRequest.folder : The folder where the file is situated.  ,
+# PostWorkbookCalculateFormulaRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_workbook_calculate_formula' } = { 
-    	summary => '',
+    	summary => 'Calculate all formulas in the workbook.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -135,35 +135,35 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'options' => {
      	datatype => 'CalculationOptions',
      	base_name => 'options',
-     	description => '',
+     	description => 'CalculationOptions Calculation Options.',
      	format => '',
      	read_only => '',
      		},
      'ignore_error' => {
      	datatype => 'string',
      	base_name => 'ignoreError',
-     	description => '',
+     	description => 'ignore Error.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
