@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,7 +59,7 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetCellsRangeMoveToRequest.name : The workbook name.  ,
+# PostWorksheetCellsRangeMoveToRequest.name : The file name.  ,
 # PostWorksheetCellsRangeMoveToRequest.sheetName : The worksheet name.  ,
 # PostWorksheetCellsRangeMoveToRequest.range : range in worksheet   ,
 # PostWorksheetCellsRangeMoveToRequest.destRow : The start row of the dest range.  ,
@@ -76,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_cells_range_move_to' } = { 
-    	summary => 'Moves the current range to the dest range.            ',
+    	summary => 'Move the current range to the destination range.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -147,7 +147,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
