@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetListObjectConvertToRangeRequest.name :   ,
-# PostWorksheetListObjectConvertToRangeRequest.sheetName :   ,
-# PostWorksheetListObjectConvertToRangeRequest.listObjectIndex :   ,
-# PostWorksheetListObjectConvertToRangeRequest.folder :   ,
-# PostWorksheetListObjectConvertToRangeRequest.storageName :    
+# PostWorksheetListObjectConvertToRangeRequest.name : The file name.  ,
+# PostWorksheetListObjectConvertToRangeRequest.sheetName : The worksheet name.  ,
+# PostWorksheetListObjectConvertToRangeRequest.listObjectIndex : List object index.  ,
+# PostWorksheetListObjectConvertToRangeRequest.folder : The folder where the file is situated.  ,
+# PostWorksheetListObjectConvertToRangeRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_list_object_convert_to_range' } = { 
-    	summary => '',
+    	summary => 'Convert list object to range in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -137,35 +137,35 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'list_object_index' => {
      	datatype => 'int',
      	base_name => 'listObjectIndex',
-     	description => '',
+     	description => 'List object index.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
