@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,13 +59,13 @@ sub new {
 
 
 # Run Operation Request
-# PutInsertNewWorksheetRequest.name :   ,
-# PutInsertNewWorksheetRequest.sheetName :   ,
+# PutInsertNewWorksheetRequest.name : The file name.  ,
+# PutInsertNewWorksheetRequest.sheetName : The worksheet name.  ,
 # PutInsertNewWorksheetRequest.index :   ,
-# PutInsertNewWorksheetRequest.sheettype :   ,
+# PutInsertNewWorksheetRequest.sheettype : Specifies the worksheet type(VB/Worksheet/Chart/BIFF4Macro/InternationalMacro/Other/Dialog).  ,
 # PutInsertNewWorksheetRequest.newsheetname :   ,
-# PutInsertNewWorksheetRequest.folder :   ,
-# PutInsertNewWorksheetRequest.storageName :    
+# PutInsertNewWorksheetRequest.folder : The folder where the file is situated.  ,
+# PutInsertNewWorksheetRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -76,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_insert_new_worksheet' } = { 
-    	summary => '',
+    	summary => 'Insert a new worksheet in the workbook.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -143,14 +143,14 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
@@ -164,7 +164,7 @@ __PACKAGE__->method_documentation({
      'sheettype' => {
      	datatype => 'string',
      	base_name => 'sheettype',
-     	description => '',
+     	description => 'Specifies the worksheet type(VB/Worksheet/Chart/BIFF4Macro/InternationalMacro/Other/Dialog).',
      	format => '',
      	read_only => '',
      		},
@@ -178,14 +178,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
