@@ -61,6 +61,7 @@ sub new {
 # Run Operation Request
 # PutWorkbookBackgroundRequest.name : The file name.  ,
 # PutWorkbookBackgroundRequest.picPath : The picture full path.  ,
+# PutWorkbookBackgroundRequest.imageAdaptOption :   ,
 # PutWorkbookBackgroundRequest.folder : The folder where the file is situated.  ,
 # PutWorkbookBackgroundRequest.storageName : The storage name where the file is situated.  ,
 # PutWorkbookBackgroundRequest.File : File to upload   
@@ -108,6 +109,10 @@ sub run_http_request {
         $query_params->{'picPath'} = $client->to_query_value($self->pic_path);      
     }
 
+    if(defined $self->image_adapt_option){
+        $query_params->{'imageAdaptOption'} = $client->to_query_value($self->image_adapt_option);      
+    }
+
     if(defined $self->folder){
         $query_params->{'folder'} = $client->to_query_value($self->folder);      
     }
@@ -149,6 +154,13 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'image_adapt_option' => {
+     	datatype => 'string',
+     	base_name => 'imageAdaptOption',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
@@ -176,6 +188,7 @@ __PACKAGE__->method_documentation({
 __PACKAGE__->attribute_map( {
     'name' => 'name',
     'pic_path' => 'picPath',
+    'image_adapt_option' => 'imageAdaptOption',
     'folder' => 'folder',
     'storage_name' => 'storageName',
     'file' => 'File' 
